@@ -1,6 +1,6 @@
 package MooseX::StrictConstructor;
 BEGIN {
-  $MooseX::StrictConstructor::VERSION = '0.14';
+  $MooseX::StrictConstructor::VERSION = '0.15';
 }
 
 use strict;
@@ -12,19 +12,13 @@ use Moose::Util::MetaRole;
 use MooseX::StrictConstructor::Role::Object;
 
 {
-    my %class_meta;
+    my %class_meta = ( class => ['MooseX::StrictConstructor::Trait::Class'] );
+
 
     if ( $Moose::VERSION < 1.9900 ) {
         require MooseX::StrictConstructor::Trait::Method::Constructor;
-        %class_meta = (
-            constructor => [
-                'MooseX::StrictConstructor::Trait::Method::Constructor']
-        );
-    }
-    else {
-        require MooseX::StrictConstructor::Trait::Class;
-        %class_meta
-            = ( class => ['MooseX::StrictConstructor::Trait::Class'] );
+        $class_meta{constructor}
+            = ['MooseX::StrictConstructor::Trait::Method::Constructor'];
     }
 
     Moose::Exporter->setup_import_methods(
@@ -47,7 +41,7 @@ MooseX::StrictConstructor - Make your object constructors blow up on unknown att
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
